==> mysql-workbench_5.2.40+dfsg.orig.tar.xz: mysql-workbench-5.2.40/library/forms/gtk/lf_textbox.h <==
/* 
 * Copyright (c) 2008, 2010, Oracle and/or its affiliates. All rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; version 2 of the
 * License.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
#ifndef _LF_TEXTBOX_H_
#define _LF_TEXTBOX_H_

#include <mforms/mforms.h>

#include "lf_view.h"


namespace mforms {
namespace gtk {

class TextBoxImpl : public ViewImpl
{
  Gtk::ScrolledWindow *_swin;
  Gtk::TextView *_text;

  TextBoxImpl(::mforms::TextBox *self, mforms::ScrollBars scroll_type);

  virtual Gtk::Widget *get_outer() const { return _swin; }
  virtual Gtk::Widget *get_inner() const { return _text; }

  static bool create(::mforms::TextBox *self, mforms::ScrollBars scroll_type);
  static void set_text(::mforms::TextBox *self, const std::string &text);
  static void append_text(::mforms::TextBox *self, const std::string &text, bool scroll_to_end);
  static std::string get_text(::mforms::TextBox *self);
  static void set_read_only(::mforms::TextBox *self, bool flag);
  static void set_padding(::mforms::TextBox *self, int pad);
  static void set_bordered(::mforms::TextBox *self, bool flag);
  static void set_monospaced(::mforms::TextBox *self, bool flag);
  static void get_selected_range(::mforms::TextBox *self, int &start, int &end);
  static void clear(::mforms::TextBox *self);

public:
  static void init();
};

  };
};

#endif

==> mysql-workbench_6.0.8+dfsg.orig.tar.xz: mysql-workbench-6.0.8/library/forms/gtk/lf_textbox.h <==
/* 
 * Copyright (c) 2008, 2012, Oracle and/or its affiliates. All rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; version 2 of the
 * License.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
#ifndef _LF_TEXTBOX_H_
#define _LF_TEXTBOX_H_

#include <mforms/mforms.h>

#include "lf_view.h"


namespace mforms {
namespace gtk {

class TextBoxImpl : public ViewImpl
{
  Gtk::ScrolledWindow *_swin;
  Gtk::TextView *_text;
//  Glib::RefPtr<Gtk::TextBuffer::Tag> tag_for_text_attributes(const mforms::TextAttributes &attr);

  TextBoxImpl(::mforms::TextBox *self, mforms::ScrollBars scroll_type);

  virtual Gtk::Widget *get_outer() const { return _swin; }
  virtual Gtk::Widget *get_inner() const { return _text; }

  static bool create(::mforms::TextBox *self, mforms::ScrollBars scroll_type);
  static void set_text(::mforms::TextBox *self, const std::string &text);
  static void append_text(::mforms::TextBox *self, const std::string &text, bool scroll_to_end);
 // static void append_text_with_attributes(::mforms::TextBox *self, const std::string &text, const ::mforms::TextAttributes &attr, bool scroll_to_end);
  static std::string get_text(::mforms::TextBox *self);
  static void set_read_only(::mforms::TextBox *self, bool flag);
  static void set_padding(::mforms::TextBox *self, int pad);
  static void set_bordered(::mforms::TextBox *self, bool flag);
  static void set_monospaced(::mforms::TextBox *self, bool flag);
  static void get_selected_range(::mforms::TextBox *self, int &start, int &end);
  static void clear(::mforms::TextBox *self);

public:
  static void init();
};

  };
};

#endif
